@@ -53,7 +53,7 @@ ci.thresholds.roc <- function(roc,
     if (length(thresholds) != 1)
       stop("'thresholds' of class character must be of length 1.")
     thresholds <- match.arg(thresholds, c("all", "best", "local maximas"))
-    thresholds.num <- as.vector(coords(roc, x=thresholds, input="threshold", ret="threshold"))
+    thresholds.num <- as.vector(coords(roc, x=thresholds, input="threshold", ret="threshold", as.list=FALSE, drop=TRUE, ...))
     attr(thresholds.num, "coords") <- thresholds
   }
   else if (is.logical(thresholds)) {
